# pytorch-show 

This is a tool to visualize models directly from py scripts  and it can automatically find all nn.Module in the file


**RUN**

`python main.py -f python_file -i 240 240 -d -n`
![img.png](img.png)
![TestModel.svg](..%2FSave%2FTestModel.svg)